Documentation
¶
Overview ¶
Package contexthook provides utilities for adding request-scoped testing hooks to contexts.
It allows observing internal engine behavior that are not exposed through the public API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ExecuteCommand ¶
type ExecuteCommand struct {
CommandEnvelope *envelopepb.Envelope
}
ExecuteCommand a hook type that is invoked when a command is executed directly via the engine's [dogma.CommandExecutor] implementation.
It is called after the command is packed into an envelope, but before the command is added to the queue.
Click to show internal directories.
Click to hide internal directories.